<!DOCTYPE html>
{% extends 'layout.html' %}
{% block content %}
<section class="">
    <div class="container bg" id="navbar">
        {% include 'project_navbar.html' %}
    </div>
    <div class="container tab-area mt-4 p-4 rounded-3">
        <div class="tab-content">
            <div class="tab-pane" id="tab-edit-project" role="tabpanel" aria-labelledby="tab-edit-project-tab"></div>
            <div class="tab-pane" id="tab-edit-other-files" role="tabpanel" aria-labelledby="tab-edit-other-files-tab">
            </div>
            <div class="tab-pane" id="tab-import-data" role="tabpanel" aria-labelledby="tab-import-data-tab">
            </div>
            <div class="tab-pane" id="tab-select-directories" role="tabpanel" aria-labelledby="tab-set-collections-tab">
            </div>
            <div class="tab-pane" id="tab-set-collections" role="tabpanel" aria-labelledby="tab-set-collections-tab">
            </div>
            <div class="tab-pane" id="tab-prepare-metadata" role="tabpanel" aria-labelledby="tab-prepare-metadata-tab">
            </div>
            <div class="tab-pane" id="tab-check-metadata" role="tabpanel" aria-labelledby="tab-check-metadata-tab">
            </div>
            <div class="tab-pane" id="tab-prepare-upload" role="tabpanel" aria-labelledby="tab-prepare-upload-tab">
            </div>
            <div class="tab-pane" id="tab-check-results" role="tabpanel" aria-labelledby="tab-check-results-tab">
            </div>
            <div class="tab-pane" id="tab-publication" role="tabpanel" aria-labelledby="tab-publication-tab"></div>
        </div>

        <!-- <a href="#" class="m-4 text-muted helper position-fixed bottom-0 end-0 mx-5"
            data-bs-toggle="Contact ... for help" title="Need help?">
            <i class="bi bi-question-circle fs-1"></i>
        </a> -->
    </div>
</section>
{% endblock %}